//@line 36 "/builds/slave/rel-192-lnx-rpk-3/l10n-mozilla-1.9.2/hu/browser/firefox-l10n.js"

//@line 38 "/builds/slave/rel-192-lnx-rpk-3/l10n-mozilla-1.9.2/hu/browser/firefox-l10n.js"

pref("general.useragent.locale", "hu");
